@@ -1,6 +1,6 @@
 /*
-    Virtual Piano Widget for Qt5
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Virtual Piano Widget for Qt
+    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -434,7 +434,6 @@ void PianoKeybd::initialize()
 #endif
     setOptimizationFlag(DontSavePainterState, true);
     setOptimizationFlag(DontAdjustForAntialiasing, true);
-    resetRawKeyboardMap();
 }
 
 /**
@@ -448,9 +447,46 @@ void PianoKeybd::resizeEvent(QResizeEvent *event)
     fitInView(d->m_scene->sceneRect(), Qt::KeepAspectRatio);
 }
 
+/**
+ * This method overrides QGraphicsView::viewportEvent()
+ * Only touchscreen events are processed here.
+ * @param ev The viewport event
+ * @return true if the event has been consumed, false otherwise
+ */
+bool PianoKeybd::viewportEvent(QEvent *ev)
+{
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
+    static const auto touchScreen = QTouchDevice::DeviceType::TouchScreen;
+#else
+    static const auto touchScreen = QInputDevice::DeviceType::TouchScreen;
+#endif
+    switch(ev->type()) {
+    case QEvent::TouchBegin:
+    case QEvent::TouchUpdate:
+    case QEvent::TouchEnd:
+    case QEvent::TouchCancel:
+    {
+        //qDebug() << Q_FUNC_INFO << ev->type();
+        QTouchEvent *touchEvent = static_cast<QTouchEvent*>(ev);
+        if (isTouchEnabled() && (touchEvent->device()->type() == touchScreen)) {
+            return d->m_scene->touchScreenEvent(touchEvent);
+        }
+        break;
+    }
+    default:
+        break;
+    }
+    return QGraphicsView::viewportEvent(ev);
+}
+
 /**
  * This method changes the number of displayed keys
  * and the starting key number, keeping the other settings the same.
+ * The common industrial piano layout has 88 keys, and starts with A, so
+ * the default starting key value is 9. But any natural note/key
+ * number is possible as starting note key.
+ * The key/note values are: C=0, D=2, E=4, F=5, G=7, A=9, B=11.
+ * @see numKeys(), startKey(), setStartKey()
  * @param numKeys The new number of keys
  * @param startKey The number of the starting key
  */
@@ -558,6 +594,80 @@ bool PianoKeybd::getUseKeyPictures() const
     return d->m_scene->getUseKeyPictures();
 }
 
+/**
+ * @brief Enables or disables the application level usage of a native event filter
+ *
+ * The native event filter should process low level keyboard events,
+ * calling the methods of the @ref RawKbdHandler interface. This method should be
+ * used in this case to indicate that the keyboard events should be ignored
+ * by the piano scene keyboard event handlers.
+ * Note: this is only necessary if the native filter does not block events.
+ * @param newState of the application level usage of a native event filter
+ */
+void PianoKeybd::setUsingNativeFilter(const bool newState)
+{
+    d->m_scene->setUsingNativeFilter( newState );
+}
+
+/**
+ * @brief Returns whether the application is filtering native events
+ *
+ * The native event filter should process low level keyboard events,
+ * calling the methods of the @ref RawKbdHandler interface.
+ * @return true if the application is filtering native events
+ */
+bool PianoKeybd::isUsingNativeFilter() const
+{
+    return d->m_scene->isUsingNativeFilter();
+}
+
+/**
+ * @brief Enables or disables the octave subscript designation
+ *
+ * According to the Scientific pitch notation (SPN), also known as
+ * American standard pitch notation (ASPN), the octave designation
+ * should be written as a subscript, but it is an user choice.
+ * 
+ * @see octaveSubscript()
+ * @param enable or disable using subscript octave numbers
+ * @since 2.7.0
+ */
+void PianoKeybd::setOctaveSubscript(const bool enable)
+{
+    d->m_scene->setOctaveSubscript( enable );
+}
+
+/**
+ * @brief Returns whether the octave subscript designation is enabled
+ *
+ * According to the Scientific pitch notation (SPN), also known as
+ * American standard pitch notation (ASPN), the octave designation
+ * should be written as a subscript.
+ * @see setOctaveSubscript()
+ * @return true if the octave subscript designation is enabled
+ * @since 2.7.0
+ */
+bool PianoKeybd::octaveSubscript() const
+{
+    return d->m_scene->octaveSubscript();
+}
+
+/** 
+ * @brief Sets the initial/starting note key
+ * 
+ * The common industrial piano keys layout (88 keys) starts with A, so
+ * the default starting key value is 9. But any natural note/key
+ * number is possible as starting note key.
+ * The key/note values are: C=0, D=2, E=4, F=5, G=7, A=9, B=11.
+ * @see setNumKeys()
+ * @since 2.7.0
+ * @param startKey is a note/key number between 0 and 11
+ */
+void PianoKeybd::setStartKey(const int startKey)
+{
+    setNumKeys(numKeys(), startKey);
+}
+
 /**
  * Returns the base octave number.
  * @see setBaseOctave()
@@ -876,6 +986,7 @@ KeyboardMap* PianoKeybd::getKeyboardMap()
 void PianoKeybd::resetRawKeyboardMap()
 {
     d->m_rawMap = &g_DefaultRawKeyMap;
+    d->m_scene->setKeyboardMap(&g_DefaultRawKeyMap);
 }
 
 /**
@@ -911,6 +1022,7 @@ void PianoKeybd::resetKeyboardMap()
 void PianoKeybd::setRawKeyboardMap(KeyboardMap *m)
 {
     d->m_rawMap = m;
+    d->m_scene->setKeyboardMap(m);
 }
 
 /**
